\name{beta.cauchy}
\alias{beta.cauchy}
\title{Function beta for the quasi-Cauchy prior}
\description{
  Given a value or vector \eqn{x} of values, find the value(s) of the function 
\eqn{\beta(x)=g(x)/\phi(x) - 1}{beta(x) = g(x)/\phi(x) - 1 },
where \eqn{g} is the convolution of the quasi-Cauchy with the normal density.  
}
\usage{
beta.cauchy(x)
}
\arguments{
  \item{x}{a real value or vector}
}
\value{
  A vector the same length as \eqn{x}, containing the value(s) \eqn{\beta(x)}{beta(x)}.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{ \code{\link{beta.laplace}}}
\examples{
beta.cauchy(c(-2,1,0,-4,8,50))
}
\keyword{nonparametric}

\eof
\name{beta.laplace}
\alias{beta.laplace}
\title{Function beta for the Laplace prior}
\description{
  Given a value or vector \eqn{x} of values, find the value(s) of the function 
\eqn{\beta(x)=g(x)/\phi(x) - 1}{beta(x) = g(x)/phi(x) - 1 },
where \eqn{g} is the convolution of the Laplace density with scale parameter \eqn{a} with  with the normal density.  
}
\usage{
beta.laplace(x, a = 0.5)
}
\arguments{
  \item{x}{the value or vector of data values}
  \item{a}{the scale parameter of the Laplace distribution}
}
\value{
  A vector the same length as \eqn{\code{x}}{x} is returned, containing the value(s) \eqn{\beta(\code{x})}{beta(x)}.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{ 
The Laplace density is given by 
\eqn{\gamma(u) = \frac{1}{2} a e^{-a|u|}}{gamma(u)= (a/2) exp ( - a|u| ) } 
and is also known as the double exponential density.}
\seealso{ \code{\link{beta.cauchy}}}
\examples{
beta.laplace(c(-2,1,0,-4,8,50))
beta.laplace(c(-2,1,0,-4,8,50), a=1)
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{cauchy.medzero}
\alias{cauchy.medzero}
\title{Objective function for quasi-Cauchy posterior median}
\description{
The objective function that has to be zeroed, component by component, 
to find the 
posterior median when the quasi-Cauchy prior is used. 
}
\usage{
cauchy.medzero(x, z, w)
}
\arguments{
  \item{x}{vector of parameter values (may be scalar)}
  \item{z}{data vector or value}
  \item{w}{prior probability that parameter is nonzero}
}
\value{
vector of values of objective function
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{postmed.cauchy}}}
\keyword{internal}

\eof
\name{cauchy.threshzero}
\alias{cauchy.threshzero}
\title{Objective function for quasi-Cauchy threshold}
\description{
The objective function that has to be zeroed
to find the posterior median threshold when the quasi-Cauchy prior is used
}
\usage{
cauchy.threshzero(z, w)
}
\arguments{
  \item{z}{vector of putative threshold values}
  \item{w}{vector of prior probabilities that parameter is nonzero (can be scalar)}
}
\details{
The function is called by the routine \code{\link{tfromw}} 
which finds the threshold for particular weight(s) \code{w}.
}
\value{
Vector of objective function values
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{ 
\code{\link{laplace.threshzero}},
\code{\link{tfromw}}}
\keyword{internal}% at least one, from doc/KEYWORDS

\eof
\name{ebayesthresh}
\alias{ebayesthresh}
\title{Empirical Bayes thresholding on a sequence}
\description{
Given a sequence of data, performs Empirical Bayes thresholding, 
as discussed in Johnstone and Silverman (2004).   
}
\usage{
ebayesthresh(x, prior = "laplace", a = 0.5, bayesfac = FALSE, 
       sdev = 1, verbose = FALSE, threshrule = "median")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{vector of data values}
  \item{prior}{%
	specification of prior to be used 
	conditional on the mean being nonzero; 
	can be \code{cauchy} or \code{laplace}
	}
  \item{a}{%
	scale factor if Laplace prior is used.  
	Ignored if Cauchy prior is used. 
	If, on entry, \code{a=NA} and \code{prior="laplace"}, then the scale 
	parameter will also be estimated by marginal maximum likelihood. 
	If \code{a} is not specified then the default value 0.5 will be used.
	}
  \item{bayesfac}{
	if \code{bayesfac=TRUE}, then whenever a threshold is explicitly 
	calculated, the Bayes factor threshold will be used
	}
  \item{sdev}{%
	the sampling standard deviation of the data \code{x}. 
	If, on entry, \code{sdev=NA}, then the standard deviation will be 
	estimated using the median absolute deviation from zero, 
	as \code{mad(x, center=0)}.
	}
  \item{verbose}{ controls the level of output. See below.}
  \item{threshrule}{%
	specifies the thresholding rule to be applied to the data. 
	Possible values are \code{median} (use the posterior median); 
	\code{mean} (use the posterior mean); 
	\code{hard} (carry out hard thresholding); 
	\code{soft} (carry out soft thresholding); 
	\code{none} (find various parameters, but do not carry out any thresholding).
	}
}
\details{
It is assumed that the data vector \eqn{(x_1, \ldots, x_n)} is such that each 
\eqn{x_i} is drawn independently from a normal distribution with mean 
\eqn{\theta_i} and variance \eqn{\sigma^2}.
The prior distribution of each \eqn{\theta_i} is a mixture with probability 
\eqn{1-w}
of zero and probability \eqn{w} of a given symmetric heavy-tailed distribution.
The mixing weight \eqn{w} is estimated by marginal maximum likelihood.
Given the mixing weight, and possibly a scale factor in the symmetric distribution, are estimated by marginal 
maximum likelihood.   
The resulting values are used as the hyperparameters in the prior.

The parameters can be estimated as the posterior median or the posterior mean given the data, or by
hard or soft thresholding using the posterior median threshold.  
If hard or soft thresholding is chosen, then there is the additional choice of using the
Bayes factor threshold, which is the value such that 
the posterior probability of zero is 
exactly half if the data value is equal to the threshold.  
}
\value{
If \code{verbose=FALSE}, a vector giving the values of the estimates of the underlying mean vector.

If \code{verbose=TRUE}, a list with the following elements:
 \item{muhat}{the estimated mean vector (omitted if \code{threshrule="none"})}
  \item{x }{the data vector as supplied}
  \item{threshold.sdevscale}{the threshold as a multiple of the standard deviation \code{sdev}}
\item{threshold.origscale}{ the threshold measured on the original scale of the data}
\item{prior}{ the prior that was used}
\item{w}{ the mixing weight as estimated by marginal maximum likelihood}
\item{a}{ (only present if Laplace prior used) the scale factor as supplied or estimated}
\item{bayesfac}{the value of the parameter \code{bayesfac}, determining whether Bayes factor or posterior median thresholds are used}
\item{sdev}{ the standard deviation of the data as supplied or estimated}
\item{threshrule}{ the thresholding rule used, as specified above}
}
\references{
Johnstone, I. M. and Silverman, B. W. (2004)  
Needles and straw in haystacks:  Empirical Bayes estimates of 
possibly sparse sequences.   \emph{Annals of Statistics}, \bold{32}, 1594--1649.

Johnstone, I. M. and Silverman, B. W. (2004) 
EbayesThresh:  R and S-PLUS software for Empirical Bayes thresholding.  Submitted for publication.

Johnstone, I. M. (2004)  `Function Estimation and Classical Normal Theory' 
`The Threshold Selection Problem'.   The Wald Lectures I and II, 2004.  Available from 
\url{http://www-stat.stanford.edu/~imj/}.

Johnstone, I. M. and Silverman, B. W. (2005)  
Empirical Bayes selection of wavelet thresholds.
\emph{Annals of Statistics}, \bold{33?}, to appear.


The papers by Johnstone and Silverman are available from \url{http://www.bernardsilverman.com}.   

See also
\url{http://www-stat.stanford.edu/~imj/} for further references, 
including the draft of a monograph by I. M. Johnstone.
}
\author{Bernard Silverman}
\seealso{\code{\link{tfromx}}, \code{\link{threshld}}}
\examples{
ebayesthresh(x=rnorm(100, c( rep(0,90), rep(5,10))), prior="cauchy", sdev=NA)
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{ebayesthresh.wavelet}
\alias{ebayesthresh.wavelet}
\alias{ebayesthresh.wavelet.dwt}
\alias{ebayesthresh.wavelet.wd}
\alias{ebayesthresh.wavelet.splus}
\title{
Empirical Bayes thresholding on the levels of a wavelet transform
}
\description{
Apply an Empirical Bayes thresholding approach level by level to the detail coefficients in a wavelet transform.
}
\usage{
ebayesthresh.wavelet(xtr, vscale = "independent", smooth.levels = Inf, 
      prior = "laplace", a = 0.5, bayesfac = FALSE, 
      threshrule = "median")
}
\arguments{
  \item{xtr}{%
	The wavelet transform of a vector of data. 
	The transform is obtained using one of the wavelet transform routines in \R or in S+WAVELETS. 
	Any choice of wavelet, boundary condition, etc provided by these routines can be used. 
	}
  \item{vscale}{%
	Controls the scale used at different levels of the transform. 
	If \code{vscale} is a scalar quantity, then it will be assumed that the wavelet coefficients 
	at every level have this standard deviation. 
	If \code{vscale = "independent"}, the standard deviation will be estimated from the highest level 
	of the wavelet transform and will then be used for all levels processed. 
	If \code{vscale="level"}, then the standard deviation will be estimated separately for each level processed, 
	allowing standard deviation that is level-dependent.
}
  \item{smooth.levels}{%
	the number of levels to be processed, if less than the number of 
	levels of detail calculated by the wavelet transform.
}
  \item{prior}{%
	specification of prior to be used for the coefficients at each level,
	conditional on their mean being nonzero; 
	can be \code{cauchy} or \code{laplace}
	} 
  \item{a}{%
	scale factor if Laplace prior is used.  
	Ignored if Cauchy prior is used. 
	If, on entry, \code{a=NA} and \code{prior="laplace"}, then the scale 
	parameter will also be estimated at each level by marginal maximum likelihood. 
	If \code{a} is not specified then the default value 0.5 will be used.
	}
  \item{bayesfac}{%
	if \code{bayesfac=TRUE}, then whenever a threshold is explicitly 
	calculated, the Bayes factor threshold will be used
	}
  \item{threshrule}{%
	specifies the thresholding rule to be applied to the coefficients.
	Possible values are \code{median} (use the posterior median); 
	\code{mean} (use the posterior mean); 
	\code{hard} (carry out hard thresholding); 
	\code{soft} (carry out soft thresholding); 
}
}
\details{
The routine \code{ebayesthresh.wavelet} can process a wavelet transform obtained using the routine 
\code{wd} in the WaveThresh \R package, the routines \code{dwt} or \code{modwt} in the waveslim \R package,
or one of the routines (either dwt or nd.dwt) in S+WAVELETS. 
Note that the wavelet transform must be calculated before the routine ebayesthresh.wavelet is called; the choice of wavelet,
boundary conditions, decimated vs nondecimated wavelet, and so on, are made when the wavelet transform is calculated.
Apart from some housekeeping to estimate the standard deviation if necessary, and to determine the number of levels 
to be processed, the main part of the routine is a call, for each level, to the smoothing routine \code{\link{ebayesthresh}}.
The basic notion of processing each level of detail coefficients is easily transferred to transforms 
constructed using other wavelet software. 
Similarly, it is straightforward to modify the routine to give 
other details of the wavelet transform, if necessary using the option 
\code{verbose = TRUE} in the calls to \code{\link{ebayesthresh}}.

The main routine \code{ebayesthresh.wavelet} calls the relevant one of the routines \code{ebayesthresh.wavelet.wd} (for a transform obtained from WaveThresh), \code{ebayesthresh.wavelet.dwt} (for transforms obtained from either \code{dwt} or \code{modwt} in waveslim) or \code{ebayesthresh.wavelet.splus} (for transforms obtained from S+WAVELETS.  
}
\value{
The wavelet transform (in the same format as that supplied to the routine) of the values of the estimated regression function underlying the original data.
}
\references{
Johnstone, I. M. and Silverman, B. W. (2005)  
Empirical Bayes selection of wavelet thresholds.
\emph{Annals of Statistics}, \bold{33?}, to appear.

See also the other references given for \code{\link{ebayesthresh}} and at \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}}
\seealso{\code{\link{ebayesthresh}}}
\examples{
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{isotone}
\alias{isotone}
\title{
Weighted least squares monotone regression 
}
\description{
Given a vector of data and a vector of weights, find the monotone sequence closest to the data in the sense of weighted least squares with the given weights.
}
\usage{
isotone(x, wt = rep(1, length(x)), increasing = FALSE)
}
\arguments{
  \item{x}{a vector of data}
  \item{wt}{a vector the same length as \code{x}, giving the weights to be used in the weighted least squares algorithm}
  \item{increasing}{logical variable indicating whether the required fit is to be increasing or decreasing}
}
\details{
The standard pool-adjacent-violators algorithm is used. 
Maximal decreasing subsequences are found within the current sequence. 
Each such decreasing subsequence is replaced by a constant sequence with value equal to the weighted average. 
Within the algorithm, the subsequence is replaced by a single point, 
with weight the sum of the weights within the subsequence. This process is iterated to termination. 
The resulting sequence is then unpacked back to the original ordering to give the weighted least squares monotone fit.

If \code{increasing=FALSE}, the original sequence is negated and the resulting estimate negated. 
}
\value{
The vector giving the best fitting monotone sequence is returned.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{wmonfromx}}}
\examples{
}
\keyword{internal}

\eof
\name{laplace.threshzero}
\alias{laplace.threshzero}
\title{Objective function for Laplace threshold}
\description{
The objective function that has to be zeroed 
to find the posterior median threshold when the Laplace prior is used
}
\usage{
laplace.threshzero(x, w, a = 0.5)
}
\arguments{
  \item{x}{vector of putative threshold values}
  \item{w}{vector of prior probabilities that parameter is nonzero (can be scalar)}
  \item{a}{scale parameter of the Laplace part of the prior}
}
\details{
The function is called by the routine \code{\link{tfromw}} which finds the threshold for particular weight(s) \code{w}.
}
\value{
vector of objective function values
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{The routine assumes that \eqn{\code{a} \leq 20}{a <= 20} and truncates \eqn{\code{a}}{a} to 20 if any larger value is supplied.}
\seealso{\code{\link{cauchy.threshzero}},
\code{\link{tfromw}}
}
\keyword{internal}

\eof
\name{negloglik.laplace}
\alias{negloglik.laplace}
\title{Negative log likelihood of parameters of mixed Laplace prior}
\description{
This routine calculates the negative log likelihood of the two parameters of the mixed Laplace prior.
It is intended as an auxiliary routine to be called by the 
optimization routine within \code{\link{wandafromx}}.
For reasons of numerical stability within the optimization, the prior is parametrized by the 
threshold and the scale parameter.  The routines \code{\link{tfromw}} and \code{\link{wfromt}}
establish the mapping between the threshold and the mixing weight, for any fixed value of the scale parameter.
}
\usage{
negloglik.laplace(xpar, xx)
}
\arguments{
  \item{xpar}{A vector of two parameters: 
	\code{xpar[1]} is the threshold and \code{xpar[2]} is the scale factor \code{a}.}
  \item{xx}{vector of data}
}
\value{
The negative log likelihood is returned
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{beta.laplace}},\code{\link{wandafromx}}}
\keyword{internal}% at least one, from doc/KEYWORDS

\eof
\name{postmean}
\alias{postmean}
\title{Posterior mean estimator}
\description{
Given a data value or a vector of data, find the corresponding posterior mean estimate(s) of the underlying signal value(s)
}
\usage{
postmean(x, w, prior = "laplace", a = 0.5)
}
\arguments{
  \item{x}{ a data value or a vector of data}
  \item{w}{ the value of the prior probability that the signal is nonzero }
  \item{prior}{ family of the nonzero part of the prior; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"} }
  \item{a}{the scale parameter of the nonzero part of the prior if the Laplace prior is used}
}
\value{
If \eqn{x} is a scalar, the posterior mean \eqn{E(\theta|x)}{E(theta|x)} where \eqn{\theta}{theta} is the mean of the distribution from which \eqn{x} is drawn.    If \eqn{x} is a vector with elements \eqn{x_1, ... , x_n}, then the vector returned has elements \eqn{E(\theta_i|x_i)}{E(theta_i|x_i)}, where each \eqn{x_i} has mean \eqn{\theta_i}{theta_i}, all with the given prior.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{If the quasicauchy prior is used, the argument \code{a} is ignored.
The routine calls the approprate one of \code{\link{postmean.laplace}} or \code{\link{postmean.cauchy}}.
}
\seealso{
\code{\link{postmean.laplace}},
\code{\link{postmean.cauchy}},
\code{\link{postmed}}
}
\examples{
postmean(c(-2,1,0,-4,8,50), w=0.05, prior="cauchy")
postmean(c(-2,1,0,-4,8,50), w=0.2, prior="laplace", a=0.3)
}
\keyword{nonparametric}

\eof
\name{postmean.cauchy}
\alias{postmean.cauchy}
\title{Posterior mean estimator using quasi-Cauchy prior}
\description{
Given a data value or a vector of data, find the posterior mean estimate(s) 
of the underlying signal value(s). 
The quasi-Cauchy distribution is used for the nonzero component of the prior
}
\usage{
postmean.cauchy(x, w)
}
\arguments{
  \item{x}{data value or vector of data}
  \item{w}{prior probability that signal is nonzero}
}
\value{
A value or vector of values of the estimate(s) of the mean(s) of the distribution(s) from which the 
\eqn{x} are drawn.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{The posterior mean is found by expressing the quasi-Cauchy prior as a mixture. 
The mean conditional on the mixing parameter is found and is then averaged 
over the posterior distribution of the mixing parameter, 
including the atom of probability at zero variance.
}
\seealso{
\code{\link{postmean}},
\code{\link{postmean.laplace}},
\code{\link{postmed.cauchy}}
}
\examples{
postmean.cauchy(c(-2,1,0,-4,8,50), w=0.05)
}
\keyword{nonparametric}

\eof
\name{postmean.laplace}
\alias{postmean.laplace}
\title{Posterior mean estimator using Laplace prior}
\description{Find posterior mean estimator given data, when the Laplace prior is used for the nonzero component 
of the signal}
\usage{
postmean.laplace(x, w, a = 0.5)
}
\arguments{
  \item{x}{ data value or vector of data}
  \item{w}{ prior probability that signal is nonzero}
  \item{a}{ scale parameter of Laplace part of the prior}
}
\value{
A value or vector of values of the estimate(s) of the mean(s) of the distribution(s) from which the \eqn{x} are drawn.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{
The posterior mean is found explicitly. 
The posterior probability that the parameter is nonzero is found, 
as is the posterior mean conditional on not being zero; 
the product of these is the posterior mean.
}
\seealso{
\code{\link{postmean}},
\code{\link{postmean.cauchy}},
\code{\link{postmed.laplace}}
}
\examples{
postmean.laplace(c(-2,1,0,-4,8,50), w=0.05, a=0.3)
}
\keyword{nonparametric}

\eof
\name{postmed}
\alias{postmed}
\title{Posterior median estimator}
\description{
  Given a data value or a vector of data, find the corresponding posterior median estimate(s) of the underlying signal value(s)
}
\usage{
postmed(x, w, prior = "laplace", a = 0.5)
}
\arguments{
  \item{x}{a data value or a vector of data}
  \item{w}{the value of the prior probability that the signal is nonzero }
  \item{prior}{family of the nonzero part of the prior; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"} }
  \item{a}{the scale parameter of the nonzero part of the prior if the Laplace prior is used}
}
\value{
If \eqn{x} is a scalar, the posterior median \eqn{\mbox{med}(\theta|x)}{med(theta|x)} where \eqn{\theta}{theta} 
is the mean of the distribution from which \eqn{x} is drawn.    
If \eqn{x} is a vector with elements \eqn{x_1, ... , x_n}, then the vector returned has elements 
\eqn{\mbox{med}(\theta_i|x_i)}{med(theta_i|x_i)}, where each \eqn{x_i} has mean \eqn{\theta_i}{theta_i}, 
all with the given prior.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{If the quasicauchy prior is used, the argument \code{a} is ignored.
The routine calls the approprate one of \code{\link{postmed.laplace}} or \code{\link{postmed.cauchy}}.
}
\seealso{
\code{\link{postmed.laplace}},
\code{\link{postmed.cauchy}},
\code{\link{postmean}}}
\examples{
postmed(c(-2,1,0,-4,8,50), w=0.05, prior="cauchy")
postmed(c(-2,1,0,-4,8,50), w=0.2, prior="laplace", a=0.3)
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{postmed.cauchy}
\alias{postmed.cauchy}
\title{Posterior median estimator using quasi-Cauchy prior}
\description{
Given a data value or a vector of data, find the posterior median estimate(s) 
of the underlying signal value(s). 
The quasi-Cauchy distribution is used for the nonzero component of the prior
}
\usage{
postmed.cauchy(x, w)
}
\arguments{
  \item{x}{data value or vector of data}
  \item{w}{prior probability that signal is nonzero}
}
\value{
A value or vector of values of the estimate(s) of the mean(s) of the distribution(s) from which the \eqn{x} are drawn.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{The posterior median is found by finding the zero of the function \code{\link{cauchy.medzero}}.
}
\seealso{
\code{\link{postmed}},
\code{\link{postmed.laplace}},
\code{\link{postmean.cauchy}},
\code{\link{cauchy.medzero}}
}
\examples{
postmed.cauchy (c(-2,1,0,-4,8,50), w=0.05)
}
\keyword{nonparametric} 

\eof
\name{postmed.laplace}
\alias{postmed.laplace}
\title{Posterior median estimator using Laplace prior}
\description{Find posterior median estimator given data, using the Laplace prior for the nonzero component}
\usage{
postmed.laplace(x, w, a = 0.5)
}
\arguments{
  \item{x}{ data value or vector of data}
  \item{w}{ prior probability that signal is nonzero}
  \item{a}{ scale parameter of Laplace part of the prior}
}
\value{
A value or vector of values of the estimate(s) of the mean(s) of the distribution(s) from which the \eqn{x} are drawn.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\note{The posterior median is found explicitly, without any need for the numerical solution of an equation.
}
\seealso{
\code{\link{postmed}},
\code{\link{postmed.cauchy}},
\code{\link{postmean.laplace}}
}
\examples{
postmed.laplace (c(-2,1,0,-4,8,50), w=0.05, a=0.3)
}
\keyword{nonparametric}

\eof
\name{tfromw}
\alias{tfromw}
\title{Find threshold from mixing weight}
\description{
Given a weight or vector of weights (i.e. prior probabilities that the parameter is nonzero), 
find the corresponding
threshold(s) under the specified prior.
}
\usage{
tfromw(w, prior = "laplace", bayesfac = FALSE, a = 0.5)
}
\arguments{
  \item{w}{prior weight or vector of weights}
  \item{prior}{specification of prior to be used; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"}}
  \item{bayesfac}{specifies whether Bayes factor threshold should be used instead of posterior median threshold}
  \item{a}{scale factor if Laplace prior is used.  Ignored if Cauchy prior is used.}
}
\details{
The Bayes factor method uses a threshold such that the posterior probability of zero is 
exactly half if the data value is equal to the threshold.  
If \code{bayesfac} is set to \eqn{\code{FALSE}}{FALSE} (the default) 
then the threshold is that of the posterior median function given the data value.

The routine carries out a binary search over an appropriate function, using the routine 
\code{\link{vecbinsolv}}.  
The function to be zeroed is \code{\link{beta.laplace}} or \code{\link{beta.cauchy}} 
if the Bayes factor threshold is to be found, and \code{\link{laplace.threshzero}} or 
\code{\link{cauchy.threshzero}} for the posterior median threshold.
}

\value{
The value or vector of values of the estimated threshold(s).
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{wfromx}},\code{\link{tfromx}},\code{\link{wandafromx}}}
\examples{
tfromw(c(0.05, 0.1)) 

tfromw(c(0.05, 0.1), prior="cauchy", bayesfac=TRUE)

}
\keyword{nonparametric}

\eof
\name{tfromx}
\alias{tfromx}
\title{Find threshold from data}
\description{
Given a vector of data, find the threshold corresponding to the marginal maximum likelihood choice of weight.
}
\usage{
tfromx(x, prior = "laplace", bayesfac = FALSE, a = 0.5)
}
\arguments{
  \item{x}{ vector of data}
  \item{prior}{specification of prior to be used; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"}}
\item{bayesfac}{specifies whether Bayes factor threshold should be used instead of posterior median threshold}
\item{a}{scale factor if Laplace prior is used.  Ignored if Cauchy prior is used.}
}
\details{
First, the routine \code{\link{wfromx}} is called to find the estimated weight. Then the routine \code{\link{tfromw}} is used to find the threshold.
See the documentation for these routines for more details. 
}
\value{
The numerical value of the estimated threshold is returned.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{tfromw}}, \code{\link{wfromx}}}
\examples{
tfromx(x=rnorm(100, c( rep(0,90), rep(5,10))), prior="cauchy")
}
\keyword{ nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{threshld}
\alias{threshld}
\title{Threshold data with hard or soft thresholding}
\description{
  Given a data value or a vector of data, threshold the data at a specified value, using hard or soft thresholding
}
\usage{
threshld(x, t, hard = TRUE)
}
\arguments{
  \item{x}{ a data value or a vector of data }
  \item{t}{value of threshold to be used}
  \item{hard}{ specifies whether hard or soft thresholding is applied}
}
\value{
  A value or vector of values the same length as \code{x}, containing the result of the relevant thresholding rule applied to \code{x}. 

}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{ \code{\link{ebayesthresh}}}
\examples{
threshld(-5:5, 1.4, FALSE)
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{vecbinsolv}
\alias{vecbinsolv}
\title{Solve systems of nonlinear equations based on a monotonic function}
\description{
Solve a nonlinear equation or a vector of nonlinear equations 
based on an increasing function in a specified interval
}
\usage{
vecbinsolv(zf, fun, tlo, thi, nits = 30, \dots )
}
\arguments{
  \item{zf}{the right hand side of the equation(s) to be solved}
  \item{fun}{an increasing function of a scalar argument, or a vector of such functions}
  \item{tlo}{lower limit of interval over which the solution is sought}
  \item{thi}{upper limit of interval over which the solution is sought}
  \item{nits}{number of binary subdivisions carried out}
  \item{\dots}{additional arguments to the function \code{fun}}
}
\details{
If \code{fun} is a scalar monotone function,
the routine finds a vector
\code{t} the same length as \code{x} such that, 
component-wise, \eqn{\code{fun(t) = x}}{fun(t) = x}, 
where this is possible within the interval \eqn{\code{(tlo,thi)}}{(tlo, thi)}. 
The relevant value returned is the nearer extreme to the solution if there 
is no solution in the specified range for any particular component of \code{x}.
The routine will also work if \code{fun} is a vector of monotone functions, 
allowing different functions to be considered for different components.  
The interval over which the search is conducted has to be the same for each 
component.

The accuracy of the solution is determined by the number of binary subdivisions;
if \eqn{\code{nits=30}}{nits=30} then the solution(s) will be accurate to about 9 orders of 
magnitude less than the length of the original interval \eqn{\code{(tlo, thi)}}{(tlo,thi)}.  
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{tfromw}},
\code{\link{postmed.cauchy}}
}
\keyword{internal}% at least one, from doc/KEYWORDS

\eof
\name{wandafromx}
\alias{wandafromx}
\title{Find weight and scale factor from data if Laplace prior is used}
\description{
Given a vector of data, find the marginal maximum likelihood choice of both weight and scale factor under the Laplace prior.
}
\usage{
wandafromx(x)
}
\arguments{
  \item{x}{a vector of data}
}
\details{
The parameters are found by marginal maximum likelihood. 
The search is over weights corresponding to thresholds in the range \eqn{[0, \sqrt{2 \log n}]}{[0, sqrt(2 log n)]},
where \eqn{n} is the length of the data vector.
The search uses a nonlinear optimization routine (\code{\link{optim}} in \R)
to minimize the negative log likelihood function \code{\link{negloglik.laplace}}. 
The range over which the scale factor is searched is (0.04, 3).
}
\value{
A list with values
  \item{w}{The estimated weight}
  \item{a}{The estimated scale factor}
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{wfromx}}, \code{\link{tfromw}}}
\examples{
wandafromx(rnorm(100, c( rep(0,90), rep(5,10))))
}
\keyword{nonparametric}

\eof
\name{wfromt}
\alias{wfromt}
\title{Mixing weight from posterior median threshold}
\description{
Given a threshold value, find the mixing weight for which this is the threshold of the posterior median estimator.
If a vector of threshold values is provided, the vector of corresponding weights is returned.
}
\usage{
wfromt(tt, prior = "laplace", a = 0.5)
}
\arguments{
  \item{tt}{ threshold value or vector of values}
  \item{prior}{specification of prior to be used; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"}}
  \item{a}{scale factor if Laplace prior is used.  Ignored if Cauchy prior is used. }
}
\value{
  The numerical value or vector of values of the corresponding weight is returned.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{ \code{\link{tfromw}}}
}
\examples{
wfromt( c(2,3,5), prior="cauchy" )
}
\keyword{ nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{wfromx}
\alias{wfromx}
\title{Find Empirical Bayes weight from data}
\description{
Suppose the vector \eqn{(x_1, \ldots, x_n)} is such that \eqn{x_i} is drawn independently from 
a normal distribution with mean \eqn{\theta_i}{\theta_i} and variance 1.
The prior distribution of the \eqn{\theta_i}{theta_i} is a mixture with probability \eqn{1-w}
of zero and probability \eqn{w} of a given symmetric heavy-tailed distribution.
This routine finds the marginal maximum likelihood estimate of the parameter \eqn{w}.
}
\usage{
wfromx(x, prior = "laplace", a = 0.5)
}
\arguments{
  \item{x}{vector of data}
  \item{prior}{specification of prior to be used; can be \eqn{\code{"cauchy"}}{"cauchy"} or 
\eqn{\code{"laplace"}}{"laplace"}}
  \item{a}{scale factor if Laplace prior is used.  Ignored if Cauchy prior is used. }
}
\details{
The weight is found by marginal maximum likelihood. The search is over weights corresponding to thresholds 
in the range 
\eqn{[0, \sqrt{2 \log n}]}, 
where \eqn{n} is the length of the data vector.

The search is by binary search for a solution to the equation 
\eqn{S(w)=0}, where \eqn{S} is the derivative of the log likelihood.
The binary search is on a logarithmic scale in \eqn{w}.

If the Laplace prior is used, the scale parameter is fixed at the value given for \code{a}, and
defaults to 0.5 if no value is provided.  To estimate \code{a} as well as \code{w} by marginal
maximum likelihood, use the routine \code{\link{wandafromx}}.
}
\value{
The numerical value of the estimated weight.
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{\code{\link{wandafromx}}, \code{\link{tfromx}}, \code{\link{tfromw}}, \code{\link{wfromt}}
}
\examples{
wfromx(x=rnorm(100, c( rep(0,90), rep(5,10))), prior="cauchy")
}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{wmonfromx}
\alias{wmonfromx}
\title{ 
Find monotone Empirical Bayes weights from data 
}
\description{
Given a vector of data, find the marginal maximum likelihood choice of 
weight sequence subject to the constraints that the 
weights are monotone decreasing.
}
\usage{
wmonfromx(xd, prior = "laplace", a = 0.5, tol = 1e-08, maxits = 20)
}
\arguments{
  \item{xd}{a vector of data}
  \item{prior}{specification of the prior to be used; can be \code{cauchy} or 
	\code{laplace}}
  \item{a}{scale parameter in prior if \code{prior="laplace"}.  Ignored if \code{prior="cauchy"}}
  \item{tol}{absolute tolerance to within which estimates are calculated}
  \item{maxits}{maximum number of weighted least squares iterations within the calculation}
}
\details{
The weights is found by marginal maximum likelihood. 
The search is over weights corresponding to thresholds in the range 
\eqn{[0, \sqrt{2 \log n}]}, where \eqn{n} is the length of the data vector.

An iterated least squares monotone regression algorithm 
is used to maximize the log likelihood. 
The weighted least squares monotone regression routine 
\code{\link{isotone}} is used.

To turn the weights into thresholds, use the routine \code{\link{tfromw}}; 
to process the data with these thresholds, 
use the routine \code{\link{threshld}}.
}
\value{
The vector of estimated weights is returned
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{Bernard Silverman}
\seealso{ \code{\link{wfromx}}, \code{\link{isotone}}}
\examples{}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
\name{zetafromx}
\alias{zetafromx}
\title{Estimation of a parameter in the prior weight sequence in the EbayesThresh paradigm}
\description{
Suppose a sequence of data has underlying mean vector with elements \eqn{\theta_i}.
Given the sequence of data, and a vector of scale factors \code{cs} 
and a lower limit \code{pilo}, 
this routine finds
the marginal maximum likelihood
estimate of the parameter \code{zeta} such that the prior probability of \eqn{\theta_i} being 
nonzero is of the form \code{median(pilo, zeta*cs, 1)}.
}
\usage{
zetafromx(xd, cs, pilo = NA, prior = "laplace", a = 0.5)
}
\arguments{
  \item{xd}{a vector of data}
  \item{cs}{a vector of scale factors, of the same length as \code{x}}
  \item{pilo}{the lower limit for the estimated weights.  If \code{pilo=NA} it 
is calculated according to the sample size to be the weight corresponding to the universal threshold \eqn{\sqrt{2 \log n}}.}
\item{prior}{%
	specification of prior to be used 
	conditional on the mean being nonzero; 
	can be \code{cauchy} or \code{laplace}
	}
  \item{a}{%
	scale factor if Laplace prior is used.  
	Ignored if Cauchy prior is used. 
	If, on entry, \code{a=NA} and \code{prior="laplace"}, then the scale 
	parameter will also be estimated by marginal maximum likelihood. 
	If \code{a} is not specified then the default value 0.5 will be used.
	}
}
}
\details{An exact algorithm is used, based on splitting the range up for \code{\zeta} 
into subintervals over which no
element of \eqn{\zeta*\code{cs}} crosses either \code{pilo} or 1.  
Within each of these subintervals, the log likelihood is
concave and its maximum can be found to arbitrary accuracy;  
first the derivatives at each end of the interval are checked
to see if there is an internal maximum at all, and if there is this can be 
found by a binary search for a zero of
the derivative.   
Finally, the maximum of all the local maxima over these subintervals is found.
}
\value{
A list with the following elements
\item{zeta}{The value of \code{zeta} that yields the marginal maximum likelihood}
\item{w}{The weights (prior probabilities of nonzero) yielded by this value of \code{zeta}}
\item{cs}{The factors as supplied to the program}
\item{pilo}{The lower bound on the weight, either as supplied or as calculated internally}
}
\references{See \code{\link{ebayesthresh}} and \url{http://www.bernardsilverman.com}}
\author{ Bernard Silverman}
\note{Once the maximizing \code{zeta} and corresponding weights have been found, 
the thresholds can be found using the program \code{\link{tfromw}}, and
these can be used to process the original data using the routine \code{\link{threshld}}.}
\seealso{\code{\link{tfromw}}, \code{\link{threshld}}, \code{\link{wmonfromx}}, \code{\link{wfromx}}}
\examples{}
\keyword{nonparametric}% at least one, from doc/KEYWORDS

\eof
